@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -48,7 +48,7 @@ __all__ = ("Cloud9Client",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -67,7 +67,7 @@ class Exceptions:
 
 class Cloud9Client(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html)
     """
 
@@ -83,7 +83,7 @@ class Cloud9Client(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#can_paginate)
         """
 
@@ -98,7 +98,7 @@ class Cloud9Client(BaseClient):
         imageId: str = None,
         automaticStopTimeMinutes: int = None,
         ownerArn: str = None,
-        tags: List["TagTypeDef"] = None,
+        tags: Sequence["TagTypeDef"] = None,
         connectionType: ConnectionTypeType = None,
         dryRun: bool = None
     ) -> CreateEnvironmentEC2ResultTypeDef:
@@ -107,7 +107,7 @@ class Cloud9Client(BaseClient):
         Cloud (Amazon EC2) instance, and then connects from the instance to the
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.create_environment_ec2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_ec2)
         """
 
@@ -117,7 +117,7 @@ class Cloud9Client(BaseClient):
         """
         Adds an environment member to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.create_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#create_environment_membership)
         """
 
@@ -125,7 +125,7 @@ class Cloud9Client(BaseClient):
         """
         Deletes an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.delete_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment)
         """
 
@@ -133,7 +133,7 @@ class Cloud9Client(BaseClient):
         """
         Deletes an environment member from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.delete_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#delete_environment_membership)
         """
 
@@ -142,7 +142,7 @@ class Cloud9Client(BaseClient):
         *,
         userArn: str = None,
         environmentId: str = None,
-        permissions: List[PermissionsType] = None,
+        permissions: Sequence[PermissionsType] = None,
         nextToken: str = None,
         maxResults: int = None
     ) -> DescribeEnvironmentMembershipsResultTypeDef:
@@ -150,7 +150,7 @@ class Cloud9Client(BaseClient):
         Gets information about environment members for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.describe_environment_memberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_memberships)
         """
 
@@ -160,31 +160,31 @@ class Cloud9Client(BaseClient):
         """
         Gets status information for an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.describe_environment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environment_status)
         """
 
     def describe_environments(
-        self, *, environmentIds: List[str]
+        self, *, environmentIds: Sequence[str]
     ) -> DescribeEnvironmentsResultTypeDef:
         """
         Gets information about Cloud9 development environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.describe_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.describe_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#describe_environments)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#generate_presigned_url)
         """
 
@@ -194,7 +194,7 @@ class Cloud9Client(BaseClient):
         """
         Gets a list of Cloud9 development environment identifiers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.list_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_environments)
         """
 
@@ -202,23 +202,23 @@ class Cloud9Client(BaseClient):
         """
         Gets a list of the tags associated with an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#list_tags_for_resource)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds tags to an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from an Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#untag_resource)
         """
 
@@ -233,7 +233,7 @@ class Cloud9Client(BaseClient):
         """
         Changes the settings of an existing Cloud9 development environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.update_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment)
         """
 
@@ -244,7 +244,7 @@ class Cloud9Client(BaseClient):
         Changes the settings of an existing environment member for an Cloud9 development
         environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Client.update_environment_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/client.html#update_environment_membership)
         """
 
@@ -253,7 +253,7 @@ class Cloud9Client(BaseClient):
         self, operation_name: Literal["describe_environment_memberships"]
     ) -> DescribeEnvironmentMembershipsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Paginator.DescribeEnvironmentMemberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#describeenvironmentmembershipspaginator)
         """
 
@@ -262,6 +262,6 @@ class Cloud9Client(BaseClient):
         self, operation_name: Literal["list_environments"]
     ) -> ListEnvironmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/cloud9.html#Cloud9.Paginator.ListEnvironments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/paginators.html#listenvironmentspaginator)
         """
