@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     ConnectionTypeType,
@@ -78,7 +78,7 @@ _OptionalCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
         "imageId": str,
         "automaticStopTimeMinutes": int,
         "ownerArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "connectionType": ConnectionTypeType,
         "dryRun": bool,
     },
@@ -138,7 +138,7 @@ DescribeEnvironmentMembershipsRequestRequestTypeDef = TypedDict(
     {
         "userArn": str,
         "environmentId": str,
-        "permissions": List[PermissionsType],
+        "permissions": Sequence[PermissionsType],
         "nextToken": str,
         "maxResults": int,
     },
@@ -173,7 +173,7 @@ DescribeEnvironmentStatusResultTypeDef = TypedDict(
 DescribeEnvironmentsRequestRequestTypeDef = TypedDict(
     "DescribeEnvironmentsRequestRequestTypeDef",
     {
-        "environmentIds": List[str],
+        "environmentIds": Sequence[str],
     },
 )
 
@@ -303,7 +303,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -319,7 +319,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
